# Redmine - project management software
# Copyright (C) 2006-2016  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require File.expand_path('../../../test_helper', __FILE__)

class RoutingContextMenusTest < Redmine::RoutingTest
  def test_context_menus_time_entries
    should_route 'GET /time_entries/context_menu' => 'context_menus#time_entries'
    should_route 'POST /time_entries/context_menu' => 'context_menus#time_entries'
  end

  def test_context_menus_issues
    should_route 'GET /issues/context_menu' => 'context_menus#issues'
    should_route 'POST /issues/context_menu' => 'context_menus#issues'
  end
end
